@@ -73,7 +73,7 @@ class SA
    * @param initMoveCoef Initial move size.
    * @param gain Proportional control in feedback move control.
    */
-  SA(CoolingScheduleType& coolingSchedule,
+  SA(const CoolingScheduleType& coolingSchedule = CoolingScheduleType(),
      const size_t maxIterations = 1000000,
      const double initT = 10000.,
      const size_t initMoves = 1000,
@@ -90,12 +90,22 @@ class SA
    * the final objective value is returned.
    *
    * @tparam FunctionType Type of function to optimize.
+   * @tparam MatType Type of objective matrix.
+   * @tparam CallbackTypes Types of callback functions.
    * @param function Function to optimize.
    * @param iterate Starting point (will be modified).
+   * @param callbacks Callback functions.
    * @return Objective value of the final point.
    */
-  template<typename FunctionType>
-  double Optimize(FunctionType& function, arma::mat& iterate);
+  template<typename FunctionType, typename MatType, typename... CallbackTypes>
+  typename MatType::elem_type Optimize(FunctionType& function,
+                                       MatType& iterate,
+                                       CallbackTypes&&... callbacks);
+
+  //! Get the cooling schedule.
+  CoolingScheduleType CoolingSchedule() const { return coolingSchedule; }
+  //! Modify the cooling schedule.
+  CoolingScheduleType& CoolingSchedule() { return coolingSchedule; }
 
   //! Get the temperature.
   double Temperature() const { return temperature; }
@@ -134,7 +144,7 @@ class SA
 
  private:
   //! The cooling schedule being used.
-  CoolingScheduleType& coolingSchedule;
+  CoolingScheduleType coolingSchedule;
   //! The maximum number of iterations.
   size_t maxIterations;
   //! The current temperature.
@@ -170,14 +180,15 @@ class SA
    * @param sweepCounter Current counter representing how many sweeps have been
    *      completed.
    */
-  template<typename FunctionType>
+  template<typename FunctionType, typename MatType, typename... CallbackTypes>
   void GenerateMove(FunctionType& function,
-                    arma::mat& iterate,
-                    arma::mat& accept,
-                    arma::mat& moveSize,
-                    double& energy,
+                    MatType& iterate,
+                    MatType& accept,
+                    MatType& moveSize,
+                    typename MatType::elem_type& energy,
                     size_t& idx,
-                    size_t& sweepCounter);
+                    size_t& sweepCounter,
+                    CallbackTypes&... callbacks);
 
   /**
    * MoveControl() uses a proportional feedback control to determine the size
@@ -197,7 +208,8 @@ class SA
    * @param nMoves Number of moves since last call.
    * @param accept Matrix representing which parameters have had accepted moves.
    */
-  void MoveControl(const size_t nMoves, arma::mat& accept, arma::mat& moveSize);
+  template<typename MatType>
+  void MoveControl(const size_t nMoves, MatType& accept, MatType& moveSize);
 };
 
 } // namespace ens
